==> gcc-4.2.0.tar.bz2: gcc-4.2.0/libjava/classpath/java/rmi/server/LoaderHandler.java <==
/* LoaderHandler.java --
   Copyright (c) 1996, 1997, 1998, 1999 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.rmi.server;

import java.net.MalformedURLException;
import java.net.URL;

/**
 * @deprecated
 */
public interface LoaderHandler
{
  /**
   * For binary compatibility with the JDK, the string "sun.rmi.server".
   * Not actually used for anything.
   */
  String packagePrefix = "sun.rmi.server";

  /**
   * @deprecated
   */
  Class loadClass(String name)
    throws MalformedURLException, ClassNotFoundException;

  /**
   * @deprecated
   */
  Class loadClass(URL codebase, String name)
    throws MalformedURLException, ClassNotFoundException;

  /**
   * @deprecated
   */
  Object getSecurityContext(ClassLoader loader);
}

==> gcc-4.7.2.tar.bz2: gcc-4.7.2/libjava/classpath/java/rmi/server/LoaderHandler.java <==
/* LoaderHandler.java --
   Copyright (c) 1996, 1997, 1998, 1999 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.rmi.server;

import java.net.MalformedURLException;
import java.net.URL;

/**
 * @deprecated
 * @since 1.1
 */
public interface LoaderHandler
{
  /**
   * For binary compatibility with the JDK, the string "sun.rmi.server".
   * Not actually used for anything.
   */
  String packagePrefix = "sun.rmi.server";

  /**
   * @deprecated
   */
  Class<?> loadClass(String name)
    throws MalformedURLException, ClassNotFoundException;

  /**
   * @deprecated
   */
  Class<?> loadClass(URL codebase, String name)
    throws MalformedURLException, ClassNotFoundException;

  /**
   * @deprecated
   */
  Object getSecurityContext(ClassLoader loader);
}
